@@ -37,3 +37,39 @@ l_u(double x)
 {
   return(x >= 0);
 }
+
+double
+l_acsc(double x)
+{
+  return(asin(1/x));
+}
+
+double
+l_asec(double x)
+{
+  return(acos(1/x));
+}
+
+double
+l_acot(double x)
+{
+  return(atan(1/x));
+}
+
+double
+l_csc(double x)
+{
+  return(1/sin(x));
+}
+
+double
+l_sec(double x)
+{
+  return(1/cos(x));
+}
+
+double
+l_cot(double x)
+{
+  return(1/tan(x));
+}
